@@ -1,52 +1,59 @@
 from typing import List, Optional
 from ddd_objects.domain.entity import Entity, ExpiredEntity
 from .value_obj import (
-    IngressHost,
-    InstanceName,
     Username,
-    DateTime,
-    Info,
-    ImageID,
-    InternetPayType,
-    SecurityGroupID,
+    NodeLabel,
     Output,
-    Value,
-    Hostname,
-    TimeInterval,
-    KeyType,
-    Number,
-    Endpoint,
-    Status,
-    NodeName,
-    Bool,
-    Price,
-    Key,
     InstanceTypeStatus,
-    InstanceType,
-    Version,
-    IP,
-    PayType,
+    ID,
+    RegionID,
+    Endpoint,
+    Usage,
+    RecordID,
+    IngressHost,
     Command,
-    NodeType,
+    BandWidth,
+    TimeInterval,
     Type,
-    InstanceTypeStatusCategory,
+    SecurityGroupID,
+    InstanceName,
+    Number,
+    Status,
     Path,
     Time,
-    BandWidth,
-    Name,
-    ZoneID,
-    GPUType,
-    ID,
-    Password,
-    Token,
+    DNSType,
+    Key,
+    Value,
+    InstanceType,
+    NodeType,
+    Weight,
+    DomainName,
     Port,
-    Data,
-    InstanceID,
-    Usage,
-    RegionID,
-    NodeLabel,
+    ZoneID,
+    DNSLine,
+    Hostname,
+    GPUType,
+    NodeName,
+    ImageID,
+    InstanceTypeStatusCategory,
+    Name,
+    ServiceType,
+    KeyType,
+    NodeStatus,
+    InternetPayType,
+    Version,
+    Bool,
+    Password,
     Size,
-    NodeStatus
+    IP,
+    Info,
+    InstanceID,
+    Price,
+    Subdomain,
+    Data,
+    Token,
+    PayType,
+    DateTime
 )
 
 class Condition(Entity):
@@ -379,7 +386,7 @@ class InstanceUsageInfo(ExpiredEntity):
         disk_usage: Usage,
         io_in: Number,
         io_out: Number,
-        _life_time: Number = Number(30)
+        _life_time: Number = Number(5)
     ):
         self.instance_id=instance_id
         self.instance_name=instance_name
@@ -404,7 +411,7 @@ class NodeMeta(ExpiredEntity):
         run_time: Time,
         k3s_version: Version,
         label: NodeLabel,
-        _life_time: Number = Number(30)
+        _life_time: Number = Number(5)
     ):
         self.name=name
         self.status=status
@@ -420,7 +427,7 @@ class Namespace(ExpiredEntity):
         name: Name,
         status: Status,
         age: TimeInterval,
-        _life_time: Number = Number(60)
+        _life_time: Number = Number(5)
     ):
         self.name=name
         self.status=status
@@ -434,7 +441,7 @@ class Secret(ExpiredEntity):
         name: Name,
         age: TimeInterval,
         namespace: Name,
-        _life_time: Number = Number(60)
+        _life_time: Number = Number(5)
     ):
         self.name=name
         self.age=age
@@ -448,7 +455,7 @@ class ConfigMap(ExpiredEntity):
         name: Name,
         age: TimeInterval,
         namespace: Name,
-        _life_time: Number = Number(60)
+        _life_time: Number = Number(5)
     ):
         self.name=name
         self.age=age
@@ -491,7 +498,7 @@ class Deployment(ExpiredEntity):
         age: TimeInterval,
         namespace: Name,
         ready_info: Info,
-        _life_time: Number = Number(30)
+        _life_time: Number = Number(5)
     ):
         self.name=name
         self.age=age
@@ -504,17 +511,23 @@ class Pod(ExpiredEntity):
     def __init__(
         self,
         name: Name,
+        node_name: NodeName,
         status: Status,
         age: TimeInterval,
+        pod_ip: IP,
         namespace: Name,
         restarts: Number,
-        _life_time: Number = Number(30)
+        readiness_info: Optional[Info],
+        _life_time: Number = Number(5)
     ):
         self.name=name
+        self.node_name=node_name
         self.status=status
         self.age=age
+        self.pod_ip=pod_ip
         self.namespace=namespace
         self.restarts=restarts
+        self.readiness_info=readiness_info
         self._life_time=_life_time
         super().__init__(_life_time)
 
@@ -555,7 +568,7 @@ class Ingress(ExpiredEntity):
         port: Number,
         age: DateTime,
         namespace: Name,
-        _life_time: Number = Number(60)
+        _life_time: Number = Number(5)
     ):
         self.name=name
         self.host_info=host_info
@@ -565,11 +578,46 @@ class Ingress(ExpiredEntity):
         self.namespace=namespace
         self._life_time=_life_time
         super().__init__(_life_time)
-    
-    @property
-    def hosts(self):
-        return [IngressHost(h) for h in self.host_info.get_value().split(',')]
-    
-    @property
-    def addresses(self):
-        return [Value(a) for a in self.address_info.get_value().split(',')]
\ No newline at end of file
+
+class DNSRecord(Entity):
+    def __init__(
+        self,
+        domain_name: DomainName,
+        subdomain: Subdomain,
+        value: Value,
+        id: Optional[RecordID] = None,
+        weight: Optional[Weight] = None,
+        dns_type: DNSType = DNSType('A'),
+        ttl: Number = Number(600),
+        priority: Optional[Number] = None,
+        line: Optional[DNSLine] = None
+    ):
+        self.domain_name=domain_name
+        self.subdomain=subdomain
+        self.value=value
+        self.id=id
+        self.weight=weight
+        self.dns_type=dns_type
+        self.ttl=ttl
+        self.priority=priority
+        self.line=line
+
+class Service(ExpiredEntity):
+    def __init__(
+        self,
+        name: Name,
+        service_type: ServiceType,
+        cluster_ip: IP,
+        external_ip: Optional[IP],
+        port_info: Info,
+        age: DateTime,
+        _life_time: Number = Number(5)
+    ):
+        self.name=name
+        self.service_type=service_type
+        self.cluster_ip=cluster_ip
+        self.external_ip=external_ip
+        self.port_info=port_info
+        self.age=age
+        self._life_time=_life_time
+        super().__init__(_life_time)
\ No newline at end of file
