@@ -19,6 +19,7 @@ from ..domain.entity import(
     CommandResult,
     Condition,
     NodeUserSetting,
+    Service,
 )
 logger = Logger()
 logger.set_labels(file_name=__file__)
@@ -62,7 +63,8 @@ from .converter import (
     ConfigMapConverter,
     DeploymentConverter,
     ConfigMapUserSettingConverter,
-    SecretUserSettingConverter
+    SecretUserSettingConverter,
+    ServiceConverter
 )
 from ..domain.repository import (
     K3SRepository
@@ -81,6 +83,7 @@ pod_converter = PodConverter()
 secret_converter = SecretConverter()
 pod_oss_operation_info_converter = PodOSSOperationInfoConverter()
 ingress_converter = IngressConverter()
+service_converter = ServiceConverter()
 
 
 class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
@@ -355,4 +358,24 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
             converter=None,
             cluster_name=cluster_name,
             namespace_name=namespace_name
+        )
+
+    def _get_services(self, cluster_name: Name, namespace_name: Name)->Optional[List[Service]]:
+        cluster_name = cluster_name.get_value()
+        namespace_name = namespace_name.get_value()
+        result = self.ao.get_services(cluster_name, namespace_name)
+        if result.succeed:
+            return [service_converter.to_entity(x) for x in result.get_value()]
+        else:
+            self.log_func(result.error_traceback)
+            return None
+
+    def get_services(self, cluster_name: Name, namespace_name: Name)->Optional[List[Service]]:
+        key = f'{cluster_name}:{namespace_name}:services'
+        return self.find_entity_helper(
+            self._get_services,
+            key=key,
+            converter=None,
+            cluster_name=cluster_name,
+            namespace_name=namespace_name
         )
\ No newline at end of file
